---
name: Vulnerability Report
about: Describe this issue template's purpose here.
title: "[VUL]: Security Report"
labels: vulnerabilities
assignees: ''

---

*Date Found*:
*Replicateable?*:
*Vulnerability*:
*How did you find this?*:
*Notes*:
